<?php


namespace App\Http\Controllers\Home;


use App\Http\Controllers\BaseController;
use App\Http\Logic\Home\HomeLogic;

class HomeController extends BaseController
{
    /**
     * @SWG\Get(
     *     path="/home/list",
     *     tags={"首页管理"},
     *     summary="获取省钱列表接口",
     *     description="获取省钱列表接口",
     *     produces={"application/json"},
     *     @SWG\Response(
     *         response="200",
     *         description="success",
     *          @SWG\Schema(
     *              @SWG\Property(
     *                  property="category_type_name",
     *                  type="string",
     *                  description="类型名称"
     *              ),
     *              @SWG\Property(
     *                  property="category_data",
     *                  type="array",
     *                  description="数据",
     *                  @SWG\Items(
     *                      @SWG\Property(
     *                          property="category_name",
     *                          type="string",
     *                          description="名称"
     *                      ),
     *                      @SWG\Property(
     *                          property="category_img_url",
     *                          type="string",
     *                          description="图标"
     *                      ),
     *                      @SWG\Property(
     *                          property="link_url",
     *                          type="string",
     *                          description="跳转地址"
     *                      )
     *                  )
     *              ),
     *          )
     *     ),
     *     @SWG\Response(
     *         response="403",
     *         description="fail",
     *         @SWG\Schema(ref="#/definitions/ErrorBean")
     *     )
     * )
     */
    public function getHomeList()
    {
        $datas = HomeLogic::getHomeListLogic();
        return $this->success($datas);
    }

    /**
     * @SWG\Get(
     *     path="/home/commission/list",
     *     tags={"首页管理"},
     *     summary="反钱赚钱列表接口",
     *     description="反钱赚钱列表接口",
     *     produces={"application/json"},
     *     @SWG\Parameter(
     *          name="type",
     *          in="query",
     *          description="类型(0赚钱1反钱)",
     *          type="string"
     *     ),
     *     @SWG\Response(
     *         response="200",
     *         description="success",
     *          @SWG\Schema(
     *              @SWG\Property(
     *                  property="total",
     *                  type="string",
     *                  description="总数量"
     *              ),
     *              @SWG\Property(
     *                  property="list",
     *                  type="array",
     *                  description="数据",
     *                  @SWG\Items(
     *                      @SWG\Property(
     *                          property="order_commission",
     *                          type="string",
     *                          description="订单佣金(单位为分)"
     *                      ),
     *                      @SWG\Property(
     *                          property="commission_status",
     *                          type="string",
     *                          description="佣金状态(0未结算1已结算2已退款)"
     *                      ),
     *                      @SWG\Property(
     *                          property="commission_type",
     *                          type="string",
     *                          description="佣金类型"
     *                      ),
     *                      @SWG\Property(
     *                          property="created_at",
     *                          type="string",
     *                          description="创建时间"
     *                      ),
     *                      @SWG\Property(
     *                          property="user_head_img_url",
     *                          type="string",
     *                          description="赚钱头像"
     *                      ),
     *                      @SWG\Property(
     *                          property="user_provider_head_img_url",
     *                          type="string",
     *                          description="反钱头像"
     *                      ),
     *                      @SWG\Property(
     *                          property="order_title",
     *                          type="string",
     *                          description="订单标题"
     *                      ),
     *                      @SWG\Property(
     *                          property="user_nickname",
     *                          type="string",
     *                          description="用户昵称"
     *                      )
     *                  )
     *              ),
     *          )
     *     ),
     *     @SWG\Response(
     *         response="403",
     *         description="fail",
     *         @SWG\Schema(ref="#/definitions/ErrorBean")
     *     )
     * )
     */
    public function getCommissionList()
    {
        $datas = HomeLogic::getCommissionListLogic();
        return $this->success($datas);
    }

    /**
     * @SWG\Get(
     *     path="/transfer/25/1",
     *     tags={"首页管理"},
     *     summary="获取返利链接接口",
     *     description="获取返利链接接口",
     *     produces={"application/json"},
     *     @SWG\Response(
     *         response="200",
     *         description="success",
     *          @SWG\Schema(
     *              @SWG\Property(
     *                  property="type",
     *                  type="string",
     *                  description="类型(1 h5 2小程序)"
     *              ),
     *              @SWG\Property(
     *                  property="url",
     *                  type="string",
     *                  description="h5链接"
     *              ),
     *              @SWG\Property(
     *                  property="app_id",
     *                  type="string",
     *                  description="小程序appID"
     *              ),
     *              @SWG\Property(
     *                  property="page_path",
     *                  type="string",
     *                  description="小程序路径"
     *              )
     *          )
     *     ),
     *     @SWG\Response(
     *         response="403",
     *         description="fail",
     *         @SWG\Schema(ref="#/definitions/ErrorBean")
     *     )
     * )
     */
    public function getTransferLinkurl($userId, $actId)
    {
        $data = HomeLogic::getTransferLink($actId,$userId);
        return $this->success($data);
    }
}